cmoncrawl.processor.pipeline.extractor.IExtractor
=================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. autoclass:: IExtractor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~IExtractor.__init__
      ~IExtractor.extract
   
   

   
   
   